summaryrefslogtreecommitdiff
path: root/src/core/managed/Managed.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/managed/Managed.hpp')
-rw-r--r--src/core/managed/Managed.hpp25
1 files changed, 12 insertions, 13 deletions
diff --git a/src/core/managed/Managed.hpp b/src/core/managed/Managed.hpp
index 4818c3d..8582702 100644
--- a/src/core/managed/Managed.hpp
+++ b/src/core/managed/Managed.hpp
@@ -19,7 +19,7 @@
#ifndef _OUSIA_MANAGED_HPP_
#define _OUSIA_MANAGED_HPP_
-#include "ManagedType.hpp"
+#include "Rtti.hpp"
#include "Manager.hpp"
namespace ousia {
@@ -108,25 +108,25 @@ public:
bool deleteData(const std::string &key);
/**
* Returns the ManagedType instance registered for instances of the type
* of this Managed instance.
*
* @return a reference to the registered ManagedType for this particular
* Managed class.
*/
- const ManagedType& type() const {
- return ManagedType::typeOf(typeid(*this));
+ const RttiBase &type() const
+ {
+ return typeOf(*this);
}
/**
* Returns true if this Managed instance is of the given ManagedType.
*
- * @param true if the ManagedType registered for this particular Managed
- * class is
+ * @param true if the RttiBase registered for this particular Managed
+ * class is of the given type or one of the registered parent types is of
+ * the given type.
*/
- bool isa(const ManagedType &t) const {
- return type().isa(t);
- }
+ bool isa(const RttiBase &t) const { return type().isa(t); }
};
/**
@@ -512,7 +512,6 @@ public:
*/
Managed *getOwner() const { return owner; }
};
-
}
#endif /* _OUSIA_MANAGED_HPP_ */
@@ -108,25 +108,25 @@ public:
bool deleteData(const std::string &key);
/**
- * Returns the ManagedType instance registered for instances of the type
- * of this Managed instance.
+ * Returns the RttiBase instance registered for instances of the type of
+ * this Managed instance.
*
@@ -108,25 +108,25 @@ public:
*
- * @return a reference to the registered ManagedType for this particular
+ * @return a reference to the registered RttiBase for this particular
* Managed class.
*/
@@ -108,25 +108,25 @@ public:
}
/**
- * Returns true if this Managed instance is of the given ManagedType.
+ * Returns true if this Managed instance is of the given RttiBase.
*